==> Checker-V0.3.tgz: Checker-0.3/config/French/dmstrings.m <==
$header "const char *chkr_strings[]"

$format "%s"
M_ABORT_M1		"L'option -a fait arrter Checker ici. Bye.\n"
M_HELP_M1		"Vous pouvez donner des options  Checker par la variable d'environnement CHECKEROPTS\n"
M_HELP_M2		"Les options sont:\n"
M_HELP_M3		"-s --silent          N'affiche pas le message de dbut.\n"
M_HELP_M4		"-q --quiet           idem.\n"
M_HELP_M5		"-a --abort           Arrt immdiat.\n"
M_HELP_M6		"-h --help            Affiche ce message.\n"
M_HELP_M7		"-n --nosymtab        N'utilise pas la table des symbols.\n"
M_HELP_M8		"-o=file --output=file  Redirige les message de Checker dans 'file'.\n"
M_HELP_M9		"-i=file --image=file Spcifie le fichier image (Checker le trouve pour vous)\n"
M_HELP_M10		"-p --profile         Affiche des informations de profile.\n"
M_COPY_M1		"Ce programme a t compil avec l'option '-checker'.\n"
M_COPY_M2		"Checker est un dtecteur d'accs  la mmoire.\n"
M_COPY_M3		"Checker est distribu dans l'espoir d'tre utile,\n"
M_COPY_M4		"cependant SANS AUCUNE GARANTIE; mme sans la garantie implicite de\n"
M_COPY_M5		"COMMERCIALISATION ou d'aptitude  un but particulier. Voir la GNU\n"
M_COPY_M6		"General Public License pour plus de dtails.\n"
M_COPY_M7		"Pour plus d'informations, metter CHECKEROPTS  '-h'\n"
############# for maccess.c
M_ERROR			"ERREUR"
M_2_RO_RIGHT		" L"
M_2_WO_RIGHT		" E"
M_2_RW_RIGHT		"LE"
M_IE_RIGHT_NAME		"*erreur interne*"
M_RO_RIGHT_NAME		"lecture"
M_WO_RIGHT_NAME		"criture"
M_RW_RIGHT_NAME		"modification"
############# for vprint.c
M_FROM_CHECKER		"De la part de Checker:\n"

==> Checker-V0.4.tgz: Checker-0.4/config/French/dmstrings.m <==
$header "const char *chkr_strings[]"

$format "%s"
M_ABORT_M1		"L'option -a fait arrter Checker ici. Bye.\n"
M_HELP_M1		"Vous pouvez donner des options  Checker par la variable d'environnement CHECKEROPTS\n"
M_HELP_M2		"Les options sont:\n"
M_HELP_M3		"-s --silent          N'affiche pas le message de dbut.\n"
M_HELP_M4		"-q --quiet           idem.\n"
M_HELP_M5		"-a --abort           Arrt immdiat.\n"
M_HELP_M6		"-h --help            Affiche ce message.\n"
M_HELP_M7		"-n --nosymtab        N'utilise pas la table des symbols.\n"
M_HELP_M8		"-o=file --output=file  Redirige les message de Checker dans 'file'.\n"
M_HELP_M9		"-i=file --image=file Spcifie le fichier image (Checker le trouve pour vous)\n"
M_HELP_M10		"-p --profile         Affiche des informations de profile.\n"
M_HELP_M11		"-d=xx --disable=xxx  Supprime les message pour l'addresse.\n"
M_HELP_M12		"-S --stop            Arret avant main().\n"
M_COPY_M1		"Ce programme a t compil avec l'option '-checker'.\n"
M_COPY_M2		"Checker est un dtecteur d'accs  la mmoire.\n"
M_COPY_M3		"Checker est distribu dans l'espoir d'tre utile,\n"
M_COPY_M4		"cependant SANS AUCUNE GARANTIE; mme sans la garantie implicite de\n"
M_COPY_M5		"COMMERCIALISATION ou d'aptitude  un but particulier. Voir la GNU\n"
M_COPY_M6		"General Public License pour plus de dtails.\n"
M_COPY_M7		"Pour plus d'informations, metter CHECKEROPTS  '-h'\n"
############# for maccess.c
M_ERROR			"ERREUR"
M_2_RO_RIGHT		" L"
M_2_WO_RIGHT		" E"
M_2_RW_RIGHT		"LE"
M_IE_RIGHT_NAME		"*erreur interne*"
M_RO_RIGHT_NAME		"lecture"
M_WO_RIGHT_NAME		"criture"
M_RW_RIGHT_NAME		"modification"
############# for vprint.c
M_FROM_CHECKER		"De la part de Checker:\n"
